/**
 *****************************************************************************
 * <p>
 * Copyright (c) Regents of the University of Minnesota. All Rights Reserved.
 * <p>
 * Author: Kevin Murray University of Minnesota - (murra668@umn.edu)
 * <p>
 *****************************************************************************
 */
package kinamine;

import javafx.application.Application;
import javafx.fxml.FXMLLoader;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.stage.Stage;

/**
 * Main KinaMine class. If no arguments are passed in, call KineMineGUI,
 * otherwise launch KinaMineDriver.
 *
 * @version 1.0
 * @author murra668
 */
public class KinaMine extends Application {

    /** Stage for KinaMineGUI */
    static Stage stage;

    /**
     * Entry into KinaMine.
     *
     * @param args
     * <ul>
     * <li>
     * Argument 1: Input ProteinPilot Distinct Peptide Summary.
     * </li>
     * <li>
     * Argument 2: Input Tabular FASTA database. 
     * </li>
     * <li>
     * Argument 3: Output directory 
     * </li>
     * <li>
     * Argument 4: Output group name
     * </li>
     *
     * </ul>
     *
     * @param args
     */
    public static void main(String[] args) {

        /** If no arguments present call GUI, otherwise run. */
        if (args.length == 0) {
            launch(args);
        } else {
            boolean status = KinaMineDriver.run(args, false);
            System.exit(0);
        }
    }
    
    /**
     * Calls GUI. 
     * 
     * @param stage
     * @throws Exception 
     */
    @Override
    public void start(Stage stage) throws Exception {

        this.stage = stage;
        Parent root = FXMLLoader.load(getClass().getResource("KinaMineGUI.fxml"));
        Scene scene = new Scene(root);
        stage.setTitle("KinaMine v. 1.0.00");
        stage.setScene(scene);
        stage.show();
    }
}
